@@ -137,7 +137,13 @@ QList<QAction*> ContextMenu::contextualActions()
                 }
             }
         } else if (QAction *a = action(name)) {
-            actions << a;
+            // Bug 364292: show "Remove this Panel" option only when panelcontroller is opened
+            if (name != QLatin1String("remove") || c->isUserConfiguring() ||
+                (c->containmentType() != Plasma::Types::PanelContainment
+                 && c->containmentType() != Plasma::Types::CustomPanelContainment)) {
+
+                actions << a;
+            }
         }
     }
 
@@ -171,7 +177,7 @@ QAction *ContextMenu::action(const QString &name)
             return m_logoutAction;
         }
     } else if (name == QLatin1String("lock widgets")) {
-        if (c->corona() && KAuthorized::authorizeKAction(QStringLiteral("lock widgets"))) {
+        if (c->corona()) {
             return c->corona()->actions()->action(QStringLiteral("lock widgets"));
         }
     } else if (name == QLatin1String("manage activities")) {
