@@ -32,9 +32,7 @@
 
 // Constructor
 WeatherEngine::WeatherEngine(QObject *parent, const QVariantList& args)
-        :  Plasma::DataEngine(parent, args),
-           m_networkAvailable(false),
-           m_networkAccessManager(new QNetworkAccessManager(this))
+        :  Plasma::DataEngine(parent, args)
 {
     m_reconnectTimer.setSingleShot(true);
     connect(&m_reconnectTimer, &QTimer::timeout, this, &WeatherEngine::startReconnect);
@@ -42,13 +40,10 @@ WeatherEngine::WeatherEngine(QObject *parent, const QVariantList& args)
     // Globally notify all plugins to remove their sources (and unload plugin)
     connect(this, &Plasma::DataEngine::sourceRemoved, this, &WeatherEngine::removeIonSource);
 
-    // Get the list of available plugins but don't load them
-    QNetworkAccessManager::NetworkAccessibility status = m_networkAccessManager->networkAccessible();
-    m_networkAvailable = (status == QNetworkAccessManager::Accessible ||
-                          status == QNetworkAccessManager::UnknownAccessibility);
-    connect(m_networkAccessManager, &QNetworkAccessManager::networkAccessibleChanged,
-            this, &WeatherEngine::networkStatusChanged);
+    connect(&m_networkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged,
+            this, &WeatherEngine::onOnlineStateChanged);
 
+    // Get the list of available plugins but don't load them
     connect(KSycoca::self(), static_cast<void (KSycoca::*)(const QStringList&)>(&KSycoca::databaseChanged),
             this, &WeatherEngine::updateIonList);
 
@@ -60,41 +55,6 @@ WeatherEngine::~WeatherEngine()
 {
 }
 
-/**
- * Loads an ion plugin given a plugin name found via KService.
- */
-IonInterface *WeatherEngine::loadIon(const QString& plugName)
-{
-    KPluginInfo foundPlugin;
-
-    foreach(const KPluginInfo &info, Plasma::PluginLoader::self()->listEngineInfo(QLatin1String("weatherengine"))) {
-        if (info.pluginName() == plugName) {
-            foundPlugin = info;
-            break;
-        }
-    }
-
-    if (!foundPlugin.isValid()) {
-        return nullptr;
-    }
-
-    // Load the Ion plugin, store it into a QMap to handle multiple ions.
-    Plasma::DataEngine *engine = dataEngine(foundPlugin.pluginName());
-    IonInterface *ion = qobject_cast<IonInterface*>(engine);
-
-    if (!ion) {
-        return nullptr;
-    }
-
-    ion->setObjectName(plugName);
-    connect(ion, &DataEngine::sourceAdded, this, &WeatherEngine::newIonSource);
-    connect(ion, &IonInterface::forceUpdate, this, &WeatherEngine::forceUpdate);
-
-    m_ions << plugName;
-
-    return ion;
-}
-
 /* FIXME: Q_PROPERTY functions to update the list of available plugins */
 
 void WeatherEngine::updateIonList(const QStringList &changedResources)
@@ -108,31 +68,36 @@ void WeatherEngine::updateIonList(const QStringList &changedResources)
     }
 }
 
-/**
- * SLOT: Get data from a new source
- */
-void WeatherEngine::newIonSource(const QString& source)
-{
-    IonInterface *ion = qobject_cast<IonInterface*>(sender());
-
-    if (!ion) {
-        return;
-    }
-
-    qDebug() << "newIonSource()";
-    ion->connectSource(source, this);
-}
 
 /**
  * SLOT: Remove the datasource from the ion and unload plugin if needed
  */
 void WeatherEngine::removeIonSource(const QString& source)
 {
-    IonInterface *ion = ionForSource(source);
+    QString ionName;
+    IonInterface *ion = ionForSource(source, &ionName);
     if (ion) {
         ion->removeSource(source);
+
+        // track used ions
+        QHash<QString, int>::Iterator it = m_ionUsage.find(ionName);
+
+        if (it == m_ionUsage.end()) {
+            qWarning() << "Removing ion source without being added before:" << source;
+        } else {
+            // no longer used?
+            if (it.value() <= 1) {
+                // forget about it
+                m_ionUsage.erase(it);
+                disconnect(ion, &IonInterface::forceUpdate, this, &WeatherEngine::forceUpdate);
+                qDebug() << "Ion no longer used as source:" << ionName;
+            } else {
+                --(it.value());
+            }
+        }
+    } else {
+        qWarning() << "Could not find ion to remove source for:" << source;
     }
-    qDebug() << "removeIonSource()";
 }
 
 /**
@@ -140,7 +105,7 @@ void WeatherEngine::removeIonSource(const QString& source)
  */
 void WeatherEngine::dataUpdated(const QString& source, const Plasma::DataEngine::Data& data)
 {
-    qDebug() << "dataUpdated()";
+    qDebug() << "dataUpdated() for:" << source;
     setData(source, data);
 }
 
@@ -149,21 +114,30 @@ void WeatherEngine::dataUpdated(const QString& source, const Plasma::DataEngine:
  */
 bool WeatherEngine::sourceRequestEvent(const QString &source)
 {
-    IonInterface* ion = ionForSource(source);
+    QString ionName;
+    IonInterface* ion = ionForSource(source, &ionName);
 
     if (!ion) {
-        ion = loadIon(ionNameForSource(source));
-        if (!ion) {
-            return false;
-        }
+        qWarning() << "Could not find ion to request source for:" << source;
+        return false;
+    }
+
+    // track used ions
+    QHash<QString, int>::Iterator it = m_ionUsage.find(ionName);
+    if (it == m_ionUsage.end()) {
+        m_ionUsage.insert(ionName, 1);
+        connect(ion, &IonInterface::forceUpdate, this, &WeatherEngine::forceUpdate);
+        qDebug() << "Ion now used as source:" << ionName;
+    } else {
+        ++(*it);
     }
 
     // we should connect to the ion anyway, even if the network
     // is down. when it comes up again, then it will be refreshed
     ion->connectSource(source, this);
 
-    qDebug() << "sourceRequestEvent(): Network is: " << m_networkAvailable;
-    if (!m_networkAvailable) {
+    qDebug() << "sourceRequestEvent(): Network is: " << m_networkConfigurationManager.isOnline();
+    if (!m_networkConfigurationManager.isOnline()) {
         setData(source, Data());
         return true;
     }
@@ -172,6 +146,7 @@ bool WeatherEngine::sourceRequestEvent(const QString &source)
         // it is an async reply, we need to set up the data anyways
         setData(source, Data());
     }
+
     return true;
 }
 
@@ -180,36 +155,43 @@ bool WeatherEngine::sourceRequestEvent(const QString &source)
  */
 bool WeatherEngine::updateSourceEvent(const QString& source)
 {
-    IonInterface *ion = ionForSource(source);
-    if (!ion) {
+    qDebug() << "updateSourceEvent(): Network is: " << m_networkConfigurationManager.isOnline();
+
+    if (!m_networkConfigurationManager.isOnline()) {
         return false;
     }
 
-    qDebug() << "updateSourceEvent(): Network is: " << m_networkAvailable;
-    if (!m_networkAvailable) {
+    IonInterface *ion = ionForSource(source);
+    if (!ion) {
+        qWarning() << "Could not find ion to update source for:" << source;
         return false;
     }
 
     return ion->updateSourceEvent(source);
 }
 
-void WeatherEngine::networkStatusChanged(QNetworkAccessManager::NetworkAccessibility status)
+void WeatherEngine::onOnlineStateChanged(bool isOnline)
 {
-    qDebug();
-    m_networkAvailable = status == QNetworkAccessManager::Accessible || status == QNetworkAccessManager::UnknownAccessibility;
-    if (m_networkAvailable) {
+    if (isOnline) {
+        qDebug() << "starting m_reconnectTimer";
         // allow the network to settle down and actually come up
-        m_reconnectTimer.start(5000);
+        m_reconnectTimer.start(1000);
+    } else {
+        m_reconnectTimer.stop();
     }
 }
 
 void WeatherEngine::startReconnect()
 {
-    foreach (const QString &i, m_ions) {
-        IonInterface * ion = qobject_cast<IonInterface *>(dataEngine(i));
-        qDebug() << "resetting" << ion;
+    for(QHash<QString, int>::ConstIterator it = m_ionUsage.constBegin(); it != m_ionUsage.constEnd(); ++it) {
+        const QString& ionName = it.key();
+        IonInterface * ion = qobject_cast<IonInterface *>(dataEngine(ionName));
+
         if (ion) {
+            qDebug() << "Resetting ion" << ion;
             ion->reset();
+        } else {
+            qWarning() << "Could not find ion to reset:" << ionName;
         }
     }
 }
@@ -222,33 +204,30 @@ void WeatherEngine::forceUpdate(IonInterface *ion, const QString &source)
         qDebug() << "immediate update of" << source;
         container->forceImmediateUpdate();
     } else {
-        qDebug() << "innexplicable failure of" << source;
+        qWarning() << "innexplicable failure of" << source;
     }
 }
 
-IonInterface* WeatherEngine::ionForSource(const QString& name)
+IonInterface* WeatherEngine::ionForSource(const QString& source, QString* ionName)
 {
-    const int offset = name.indexOf(QLatin1Char('|'));
+    const int offset = source.indexOf(QLatin1Char('|'));
 
     if (offset < 1) {
         return nullptr;
     }
 
-    QString ionName = name.left(offset);
-    return qobject_cast<IonInterface *>(dataEngine(ionName));
-}
+    const QString name = source.left(offset);
 
-QString WeatherEngine::ionNameForSource(const QString& source) const
-{
-    const int offset = source.indexOf(QLatin1Char('|'));
+    IonInterface* result = qobject_cast<IonInterface *>(dataEngine(name));
 
-    if (offset < 1) {
-        return QString();
+    if (result && ionName) {
+        *ionName = name;
     }
 
-    return source.left(offset);
+    return result;
 }
 
+
 K_EXPORT_PLASMA_DATAENGINE_WITH_JSON(weather, WeatherEngine, "plasma-dataengine-weather.json")
 
 #include "weatherengine.moc"
