@@ -48,6 +48,7 @@ extern "C" {
 #include <kmessagebox.h>
 #include <KConfigGroup>
 #include <QTimer>
+#include <QTime>
 #include <QMap>
 
 
@@ -63,6 +64,16 @@ class KSMClient;
 class OrgKdeKLauncherInterface;
 class QDBusInterface;
 
+enum SMType { SM_ERROR, SM_WMCOMMAND, SM_WMSAVEYOURSELF };
+struct SMData
+    {
+    SMType type;
+    QStringList wmCommand;
+    QString wmClientMachine;
+    QString wmclass1, wmclass2;
+    };
+typedef QMap<WId,SMData> WindowMap;
+
 class KSMServer : public QObject
 {
 Q_OBJECT
@@ -146,6 +157,7 @@ private:
     void completeShutdownOrCheckpoint();
     void startKilling();
     void startKillingSubSession();
+    void performStandardKilling();
     void completeKilling();
     void completeKillingSubSession();
     void killWM();
@@ -176,6 +188,15 @@ private:
     bool defaultSession() const; // empty session
     void setupXIOErrorHandler();
 
+    void performLegacySessionSave();
+    void storeLegacySession( KConfig* config );
+    void restoreLegacySession( KConfig* config );
+    void restoreLegacySessionInternal( KConfigGroup* config, char sep = ',' );
+    QStringList windowWmCommand(WId w);
+    QString windowWmClientMachine(WId w);
+    WId windowWmClientLeader(WId w);
+    QByteArray windowSessionId(WId w, WId leader);
+
     bool checkStartupSuspend();
     void finishStartup();
     void resumeStartupInternal();
@@ -183,8 +204,9 @@ private:
 
     void runShutdownScripts();
 
-    // public D-Bus interface
- public Q_SLOTS:
+    // public dcop interface
+
+ public Q_SLOTS: //public dcop interface
     void logout( int, int, int );
     bool canShutdown();
     bool isShuttingDown() const;
@@ -255,6 +277,8 @@ private:
 
     QStringList excludeApps;
 
+    WindowMap legacyWindows;
+
     OrgKdeKLauncherInterface* klauncherSignals;
     QDBusInterface* kcminitSignals;
 
