@@ -211,16 +211,18 @@ QScriptValue ScriptEngine::createActivity(QScriptContext *context, QScriptEngine
 
     qDebug() << "Setting default Containment plugin:" << plugin;
 
-    if (plugin.isEmpty() || plugin == QLatin1String("undefined")) {
-        KConfigGroup shellCfg = KConfigGroup(KSharedConfig::openConfig(env->m_corona->package().filePath("defaults")), "Desktop");
-        plugin = shellCfg.readEntry("Containment", "org.kde.desktopcontainment");
-    }
-
     ShellCorona *sc = qobject_cast<ShellCorona *>(env->m_corona);
     StandaloneAppCorona *ac = qobject_cast<StandaloneAppCorona *>(env->m_corona);
     if (sc) {
+        if (plugin.isEmpty() || plugin == QLatin1String("undefined")) {
+            plugin = sc->defaultContainmentPlugin();
+        }
         sc->insertActivity(id, plugin);
     } else if (ac) {
+        if (plugin.isEmpty() || plugin == QLatin1String("undefined")) {
+            KConfigGroup shellCfg = KConfigGroup(KSharedConfig::openConfig(env->m_corona->package().filePath("defaults")), "Desktop");
+            plugin = shellCfg.readEntry("Containment", "org.kde.desktopcontainment");
+        }
         ac->insertActivity(id, plugin);
     }
 
@@ -863,7 +865,8 @@ QScriptValue ScriptEngine::desktops(QScriptContext *context, QScriptEngine *engi
     int count = 0;
 
     foreach (Plasma::Containment *c, env->corona()->containments()) {
-        if (!isPanel(c)) {
+        //make really sure we get actual desktops, so check for a non empty activty id
+        if (!isPanel(c) && !c->activity().isEmpty()) {
             containments.setProperty(count, env->wrap(c));
             ++count;
         }
