@@ -106,6 +106,8 @@ public:
 
     KWayland::Client::PlasmaShell *waylandPlasmaShellInterface() const;
 
+    QString defaultContainmentPlugin() const;
+
 protected:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
@@ -213,6 +215,7 @@ private:
     KActivities::Controller *m_activityController;
     QHash<const Plasma::Containment *, PanelView *> m_panelViews;
     KConfigGroup m_desktopDefaultsConfig;
+    KConfigGroup m_lnfDefaultsConfig;
     QList<Plasma::Containment *> m_waitingPanels;
     QHash<QString, QString> m_activityContainmentPlugins;
     QHash<QString, QHash<int, Plasma::Containment *> > m_desktopContainments;
